#
# spec file for package flare
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           flare
Version:        1.0
Release:        lp151.2.4
Summary:        Free Libre Action Roleplaying Engine
License:        GPL-3.0-or-later AND (CC-BY-SA-3.0 OR CC-BY-SA-4.0)
Group:          Amusements/Games/RPG
Url:            http://flarerpg.org
Source0:        https://github.com/clintbellanger/flare-engine/archive/v%{version}.tar.gz#/%{name}-engine-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(SDL2_image)
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(SDL2_ttf)
Requires:       %{name}-game = %{version}
Requires(post): hicolor-icon-theme
Requires(post): update-desktop-files
Requires(postun): hicolor-icon-theme
Requires(postun): update-desktop-files
Recommends:     python
Provides:       %{name}-engine = %{version}

%description
Flare (Free Libre Action Roleplaying Engine) is a game engine built
to handle a very specific kind of game: single-player 2D action RPGs.
Flare is not a reimplementation of an existing game or engine. It is a
tribute to and exploration of the action RPG genre.

The usecase of this project is to build several real games and
reuse code. The first game, in progress, is a fantasy dungeon crawl.

Flare uses .ini-style config files for most of the
game data to modify game contents. The game code is C++.

%prep
%setup -q -n %{name}-engine-%{version}
# W: desktopfile-without-binary flare.desktop /usr/bin/flare
sed -i 's/@FLARE_EXECUTABLE_PATH@/%{name}/g' distribution/flare.desktop.in

%build
%cmake \
       -DBINDIR="bin"
make %{?_smp_mflags}

%install
%cmake_install

%if 0%{?suse_version} < 1500
%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%endif

%files
%license COPYING
%doc %attr(644,root,root) README* RELEASE_NOTES.txt
%{_bindir}/%{name}
%{_mandir}/man*/%{name}.*
%{_datadir}/games/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg

%changelog
* Wed Mar 14 2018 jengelh@inai.de
- Trim bias and filler wording from description.
* Wed Mar 14 2018 tchvatal@suse.com
- Version update to 1.0 release:
  * No real upstream changelog but first non-alpha release supporting
    big campaign mode.
- Remove unused condition for license
- Cleanup a bit
* Mon Jun 27 2016 dap.darkness@gmail.com
- Prevented openSUSE 13.1' error (invalid-license CC-BY-SA-4.0).
* Sun May 29 2016 dap.darkness@gmail.com
- Version bump to 0.20:
  * no upstream changelog.
- Tarball & spec for data subpackage.
- License, *Requires, %%description were fixed up.
- RelWithDebInfo build type to provide debuginfo.
- Verbose make.
- Valid %%post(un).
* Thu Nov 20 2014 tchvatal@suse.com
- Version bump to 0.19:
  * Lots of various improvements. See ChangeLog
- Remove _service and use rather tarball next to pkg with possiblity to
  local service run of download_files
- Use cmake macro and overall cleanup of .spec
* Sat Apr  6 2013 dap.darkness@gmail.com
- 0.18 release
  * 10 Equipment Slots, up from 4 (and easily configurable)
  * Starting "Class" choice (beginner's power/item kit)
  * Environmental/Ambient Sounds on maps
  * Much improved handling of Animations, Effects, and Sounds
  * New Powers: Stealth, Traps, Thrown Weapons
  * New Item Bonuses: XP gain, Gold Find, Item Find, and more
  * Improved support for various input devices
- Service source_validator was enabled.
- Spec header was fixed up according to distro policy.
- Sources were moved from GitHub to SourceForge.
- Spec was fixed up via `spec-cleaner`.
- Requires hicolor-icon-theme not to pack unnecessary dirs.
- Python became recommended, not required.
- xgettext.py & readme.txt might be executable.
* Tue Oct  2 2012 dap.darkness@gmail.com
- 0.17.1 release
  * Instant-sell items now go to the vendor Buyback tab
  * Disable New/Load buttons if there is no story mod loaded
  * Prevent crash when binding higher number mouse buttons
  * Prevent crash when loading a map with missing layers
  * Add helpful tooltips when play buttons are disabled
  * Removed -flto compiler flag from default build script
* Sun Sep 30 2012 dap.darkness@gmail.com
- 0.17 release
  * All menus now easy to mod/reskin
  * New Powers tree with traditional tabs and spendable points
  * Shared Stash! Collect epics, hoard resist gear, or buff your new characters
  * Warp Zone - fast-travel map to get around the alpha demo campaign
- Clean section was removed.
- Url was updated.
* Sun Jul  8 2012 dap.darkness@gmail.com
- 0.16 release
  * Improved enemy pathfinding, including flying creatures
  * Summon or transform into enemies!
  * Config menu including keybindings, mods, and more
  * Orthogonal map support
* Thu May 31 2012 dap.darkness@gmail.com
- git
  * Configuration menu was implemented
- Build improvements
  * Cmake build type became "RelWithDebInfo"
  * Cmake verbose makefile became "True"
  * Binary path fixing patch was replaced by cmake option.
  * Rpm optimisation flags were enabled.
* Sun Dec 25 2011 dap.darkness@gmail.com
- 0.15.1 release
  * Fixes a couple issues (build flags, random enemy groups)
* Fri Dec 23 2011 dap.darkness@gmail.com
- 0.15 release
  * Now using TTF for fonts
  * All game data can be overwritten/added via mods
  * Translation support for the core engine and mods
  * New Grassland tileset
  * New questing areas: Frontier and Living Bones
  * Redesigned creatures are tougher and more varied
